@@ -27,6 +27,8 @@
   *@author Miguel Novas
   */
 
+#include <stdio.h>
+
 class CpuPanel : public Panel  {
 Q_OBJECT
 public:
@@ -36,6 +38,7 @@ public:
 protected:
 
   void drawContents ( QPainter *p );
+  void paletteChange( const QPalette &oldPalette);
 
 private:
 
@@ -43,6 +46,7 @@ private:
 
   QString sCpu,sVendor,sBogomips;
 
+  void resizeEvent ( QResizeEvent *e );
 };
 
 #endif
